@@ -10,8 +10,8 @@ def to_precision(x, p):
 
     x = float(x)
 
-    if x == 0.:
-        return "0." + "0"*(p-1)
+    if x == 0.0:
+        return "0." + "0" * (p - 1)
 
     out = []
 
@@ -21,18 +21,18 @@ def to_precision(x, p):
 
     e = int(math.log10(x))
     tens = math.pow(10, e - p + 1)
-    n = math.floor(x/tens)
+    n = math.floor(x / tens)
 
     if n < math.pow(10, p - 1):
-        e = e -1
-        tens = math.pow(10, e - p+1)
+        e = e - 1
+        tens = math.pow(10, e - p + 1)
         n = math.floor(x / tens)
 
-    if abs((n + 1.) * tens - x) <= abs(n * tens -x):
+    if abs((n + 1.0) * tens - x) <= abs(n * tens - x):
         n = n + 1
 
-    if n >= math.pow(10,p):
-        n = n / 10.
+    if n >= math.pow(10, p):
+        n = n / 10.0
         e = e + 1
 
     m = "%.*g" % (p, n)
@@ -42,20 +42,20 @@ def to_precision(x, p):
         if p > 1:
             out.append(".")
             out.extend(m[1:p])
-        out.append('e')
+        out.append("e")
         if e > 0:
             out.append("+")
         out.append(str(e))
-    elif e == (p -1):
+    elif e == (p - 1):
         out.append(m)
     elif e >= 0:
-        out.append(m[:e+1])
-        if e+1 < len(m):
+        out.append(m[: e + 1])
+        if e + 1 < len(m):
             out.append(".")
-            out.extend(m[e+1:])
+            out.extend(m[e + 1 :])
     else:
         out.append("0.")
-        out.extend(["0"]*-(e+1))
+        out.extend(["0"] * -(e + 1))
         out.append(m)
 
-    return "".join(out)
\ No newline at end of file
+    return "".join(out)
